def test_gvec_spline(plot=False):

    # ============================================================
    # Imports.
    # ============================================================

    import os
    import sys
    basedir = os.path.dirname(os.path.realpath(__file__))
    sys.path.insert(0, os.path.join(basedir, '..', 'src')) # Because we are inside './test/' directory.
    if sys.version_info[0] < 3:
        from StringIO import StringIO
    else:
        from io import StringIO

    # import logging
    from gvec_to_python.util.logger import logger
    # logger = logging.getLogger(__name__)

    import numpy as np
    from gvec_to_python import GVEC, Form, Variable
    import matplotlib.pyplot as plt

    logger.info(' ')
    logger.info('='*80)
    logger.info('Running `test_gvec_spline()`.')
    logger.info('Plot splines from GVEC data.')
    logger.info('='*80)
    logger.info(' ')



    # ============================================================
    # Init GVEC class.
    # ============================================================

    filepath = 'GVEC/testcases/ellipstell/'
    filepath =  os.path.join(basedir, '..', filepath) # Because we are inside './test/' directory.
    filename = 'GVEC_ellipStell_profile_update_State_0000_00010000.json'
    gvec = GVEC(filepath, filename)



    # ============================================================
    # Setup plot.
    # ============================================================

    # Plot settings.
    row = 2
    col = 3
    dpi = 100
    width, height = (1920 / dpi, 1200 / dpi)
    fig = plt.figure(figsize=(width,height), dpi=dpi)
    gs  = fig.add_gridspec(row, col)
    fig.suptitle('Visualizion of GVEC splines', fontsize='xx-large')
    ax_X1_Bspl  = fig.add_subplot(gs[0, 0])
    ax_X2_Bspl  = fig.add_subplot(gs[0, 1])
    ax_LA_Bspl  = fig.add_subplot(gs[0, 2])
    ax_X1_dBspl = fig.add_subplot(gs[1, 0])
    ax_X2_dBspl = fig.add_subplot(gs[1, 1])
    ax_LA_dBspl = fig.add_subplot(gs[1, 2])



    # ============================================================
    # Reference spline spaces within GVEC class.
    # ============================================================

    spls = [gvec.X1_base.sbase.hylife_sbase, gvec.X2_base.sbase.hylife_sbase, gvec.LA_base.sbase.hylife_sbase]



    # ============================================================
    # Plotting.
    # ============================================================

    spls[0].plot_splines(which='B-splines',  ax=ax_X1_Bspl)
    spls[1].plot_splines(which='B-splines',  ax=ax_X2_Bspl)
    spls[2].plot_splines(which='B-splines',  ax=ax_LA_Bspl)
    spls[0].plot_splines(which='dB-splines', ax=ax_X1_dBspl)
    spls[1].plot_splines(which='dB-splines', ax=ax_X2_dBspl)
    spls[2].plot_splines(which='dB-splines', ax=ax_LA_dBspl)

    ax_X1_Bspl.set_title('X1 ' + ax_X1_Bspl.get_title(loc='center'), fontsize='x-large')
    ax_X2_Bspl.set_title('X2 ' + ax_X2_Bspl.get_title(loc='center'), fontsize='x-large')
    ax_LA_Bspl.set_title('LA ' + ax_LA_Bspl.get_title(loc='center'), fontsize='x-large')

    ax_X1_dBspl.set_title('X1 ' + ax_X1_dBspl.get_title(loc='center'), fontsize='x-large')
    ax_X2_dBspl.set_title('X2 ' + ax_X2_dBspl.get_title(loc='center'), fontsize='x-large')
    ax_LA_dBspl.set_title('LA ' + ax_LA_dBspl.get_title(loc='center'), fontsize='x-large')

    fig.tight_layout()

    if plot:
        plt.show()



if __name__ == '__main__':
    test_gvec_spline(plot=True)
